/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.enums;

import java.util.HashMap;

public class EnumMapper {

    private final HashMap<String, Class<? extends Enum<?>>> mapping;

    {
        mapping = new HashMap<String, Class<? extends Enum<?>>>();
        mapping.put("RhevmCmd.HostSelectionAlgorithm",                      PowerShellHostSelectionAlgorithm.class);
        mapping.put("VdcDAL.AuditLogSeverity",                              PowerShellLogSeverity.class);
        mapping.put("VdcDAL.BootSequence",                                  PowerShellBootSequence.class);
        mapping.put("VdcDAL.DiskType",                                      PowerShellDiskType.class);
        mapping.put("VdcDAL.HypervisorType",                                PowerShellHypervisorType.class);
        mapping.put("VdcDAL.ImageStatus",                                   PowerShellImageStatus.class);
        mapping.put("VdcDAL.NetworkStatus",                                 PowerShellNetworkStatus.class);
        mapping.put("VdcDAL.OperationMode",                                 PowerShellOperationMode.class);
        mapping.put("VdcDAL.OriginType",                                    PowerShellOriginType.class);
        mapping.put("VdcDAL.PropagateErrors",                               PowerShellPropagateErrors.class);
        mapping.put("VdcDAL.StorageDomainSharedStatus",                     PowerShellStorageDomainSharedStatus.class);
        mapping.put("VdcDAL.StorageDomainStatus",                           PowerShellStorageDomainStatus.class);
        mapping.put("VdcDAL.StorageType",                                   PowerShellStorageType.class);
        mapping.put("VdcDAL.UsbPolicy",                                     PowerShellUsbPolicy.class);
        mapping.put("VdcDAL.VdsSpmStatus",                                  PowerShellVdsSpmStatus.class);
        mapping.put("VdcDAL.VmTemplateStatus",                              PowerShellVmTemplateStatus.class);
        mapping.put("VdcDAL.VmType",                                        PowerShellVmType.class);
        mapping.put("VdcDAL.VmOsType",                                      PowerShellOsType.class);
        mapping.put("VdcDAL.VolumeFormat",                                  PowerShellVolumeFormat.class);
        mapping.put("VdcDAL.VolumeType",                                    PowerShellVolumeType.class);
        mapping.put("VdcCommon.AsyncTasks.AsyncTaskStatusEnum",             PowerShellAsyncTaskStatus.class);
        mapping.put("VdcCommon.AsyncTasks.AsyncTaskResultEnum",             PowerShellAsyncTaskResult.class);
    };

    public boolean isEnum(String type) {
        return mapping.containsKey(type);
    }

    public Enum<?> parseEnum(String type, Integer value) {
        Class<? extends Enum<?>> clz = mapping.get(type);
        Class<?>[] paramTypes = new Class<?>[] { int.class };
        try {
            return clz.cast(clz.getMethod("forValue", paramTypes).invoke(null, value));
        } catch (Exception e) {
            throw new RuntimeException("Error parsing " + clz + " enum", e);
        }
    }
}
