/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.model;

import java.util.ArrayList;
import java.util.List;

import com.redhat.rhevm.api.common.util.StatusUtils;
import com.redhat.rhevm.api.model.DataCenter;
import com.redhat.rhevm.api.model.IP;
import com.redhat.rhevm.api.model.Network;
import com.redhat.rhevm.api.model.VLAN;
import com.redhat.rhevm.api.powershell.enums.PowerShellNetworkStatus;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;

public class PowerShellNetwork {

    public static List<Network> parse(PowerShellParser parser, String output) {
        ArrayList<Network> ret = new ArrayList<Network>();

        for (PowerShellParser.Entity entity : parser.parse(output)) {
            Network network = new Network();

            network.setId(entity.get("networkid"));
            network.setName(entity.get("name"));
            network.setDescription(entity.get("description"));
            network.setStatus(StatusUtils.create(entity.get("status", PowerShellNetworkStatus.class).map()));

            DataCenter dataCenter = new DataCenter();
            dataCenter.setId(entity.get("datacenterid"));
            network.setDataCenter(dataCenter);

            if (entity.get("address") != null ||
                entity.get("subnet") != null ||
                entity.get("gateway") != null) {
                IP ip = new IP();
                ip.setAddress(entity.get("address"));
                ip.setNetmask(entity.get("subnet"));
                ip.setGateway(entity.get("gateway"));
                network.setIp(ip);
            }

            if (entity.isSet("vlanid")) {
                VLAN vlan = new VLAN();
                vlan.setId(entity.get("vlanid", Integer.class));
                network.setVlan(vlan);
            }

            network.setStp(entity.get("stp", Boolean.class));
            network.setDisplay(Boolean.TRUE.equals(entity.get("isdisplay", Boolean.class)));

            ret.add(network);
        }

        return ret;
    }
}
