/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.model;

import java.util.ArrayList;
import java.util.List;

import com.redhat.rhevm.api.model.ProductInfo;
import com.redhat.rhevm.api.model.Version;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;

public class PowerShellSystemVersion {

    private static ProductInfo parseVersion(String text) {
        ProductInfo productInfo = new ProductInfo(){{setVersion(new Version());}};
        String parts[] = text.split("\\.", -1);
        switch (parts.length) {
        case 4:
            productInfo.getVersion().setRevision(Integer.parseInt(parts[3]));
        case 3:
            productInfo.getVersion().setBuild(Integer.parseInt(parts[2]));
        case 2:
            productInfo.getVersion().setMinor(Integer.parseInt(parts[1]));
        case 1:
            productInfo.getVersion().setMajor(Integer.parseInt(parts[0]));
        }
        return productInfo;
    }

    public static List<ProductInfo> parse(PowerShellParser parser, String output) {
        List<ProductInfo> ret = new ArrayList<ProductInfo>();

        for (PowerShellParser.Entity entity : parser.parse(output)) {
            if (entity.getType().equals("System.Version")) {
                ret.add(parseVersion(entity.getValue()));
            }
        }

        return ret;
    }
}
