/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.model;

import java.util.ArrayList;
import java.util.List;

import com.redhat.rhevm.api.model.Tag;
import com.redhat.rhevm.api.model.TagParent;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;

public class PowerShellTag {

    private static final String TAGS_TYPE = "RhevmCmd.CLITag";

    static boolean isTag(PowerShellParser.Entity entity) {
        return TAGS_TYPE.equals(entity.getType());
    }

    public static List<Tag> parse(PowerShellParser parser, String output) {
        List<Tag> ret = new ArrayList<Tag>();

        for (PowerShellParser.Entity entity : parser.parse(output)) {
            ret.add(parseEntity(entity));
        }
        return ret;
    }

    public static Tag parseEntity(PowerShellParser.Entity entity){
        Tag tag = new Tag();

        tag.setId(entity.get("tagid", String.class, Integer.class).toString());
        tag.setName(entity.get("name"));
        tag.setDescription(entity.get("description"));

        tag.setParent(new TagParent());
        tag.getParent().setTag(new Tag());
        tag.getParent().getTag().setId(entity.get("parentid", String.class, Integer.class).toString());

        return tag;
    }
}
