/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import com.redhat.rhevm.api.model.Domain;
import com.redhat.rhevm.api.resource.DomainGroupsResource;
import com.redhat.rhevm.api.resource.DomainResource;
import com.redhat.rhevm.api.resource.DomainUsersResource;

public class PowerShellDomainResource implements DomainResource {

    private PowerShellDomainsResource parent;
    private String id;

    public PowerShellDomainResource(PowerShellDomainsResource parent, String id) {
        this.parent = parent;
        this.id = id;
    }

    public String getId() {
        return id;
    }

    public Domain get() {
        Domain domain = new Domain();
        domain.setId(id);
        domain.setName(id);
        return parent.addLinks(domain);
    }

    public DomainUsersResource getDomainUsersResource() {
        PowerShellDomainUsersResource resource =
            new PowerShellDomainUsersResource(this, parent.getExecutor(), parent.getPowerShellPoolMap(), parent.getParser());
        resource.setUriInfo(parent.getUriInfo());
        return resource;
    }

    public DomainGroupsResource getDomainGroupsResource() {
        PowerShellDomainGroupsResource resource =
            new PowerShellDomainGroupsResource(this, parent.getExecutor(), parent.getPowerShellPoolMap(), parent.getParser());
        resource.setUriInfo(parent.getUriInfo());
        return resource;
    }
}
