/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.util.concurrent.Executor;

import javax.ws.rs.core.Response;

import com.redhat.rhevm.api.common.resource.UriInfoProvider;
import com.redhat.rhevm.api.model.Action;
import com.redhat.rhevm.api.model.StorageDomain;
import com.redhat.rhevm.api.model.VM;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;
import com.redhat.rhevm.api.powershell.util.PowerShellPoolMap;
import com.redhat.rhevm.api.powershell.util.PowerShellUtils;
import com.redhat.rhevm.api.resource.StorageDomainContentResource;

public class PowerShellStorageDomainVmResource
    extends AbstractPowerShellStorageDomainContentResource<VM>
    implements StorageDomainContentResource<VM> {

    public PowerShellStorageDomainVmResource(PowerShellStorageDomainVmsResource parent,
                                             String vmId,
                                             Executor executor,
                                             UriInfoProvider uriProvider,
                                             PowerShellPoolMap shellPools,
                                             PowerShellParser parser) {
        super(parent, vmId, executor, uriProvider, shellPools, parser);
    }

    @Override
    public VM get() {
        StringBuilder buf = new StringBuilder();

        String dataCenterArg = getDataCenterArg(buf);

        buf.append("get-vmimportcandidates");
        buf.append(" -showall");
        buf.append(" -datacenterid " + dataCenterArg);
        buf.append(" -storagedomainid " + PowerShellUtils.escape(getStorageDomainId()));
        buf.append(" | ? { $_.vmid -eq " + PowerShellUtils.escape(getId()) + " }");

        return parent.addLinks(getUriInfo(), parent.runAndParseSingle(buf.toString()));
    }

    @Override
    protected VM getModel() {
        VM vm = super.getModel();
        vm.setStorageDomain(new StorageDomain());
        vm.getStorageDomain().setId(getStorageDomainId());
        return vm;
    }

    @Override
    public Response doImport(Action action) {
        return doImport(action, "vm");
    }
}
