/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.util.List;
import java.util.concurrent.Executor;


import com.redhat.rhevm.api.model.Tag;
import com.redhat.rhevm.api.resource.TagResource;
import com.redhat.rhevm.api.common.resource.UriInfoProvider;
import com.redhat.rhevm.api.common.util.LinkHelper;
import com.redhat.rhevm.api.powershell.model.PowerShellTag;
import com.redhat.rhevm.api.powershell.util.PowerShellCmd;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;
import com.redhat.rhevm.api.powershell.util.PowerShellPool;
import com.redhat.rhevm.api.powershell.util.PowerShellPoolMap;
import com.redhat.rhevm.api.powershell.util.PowerShellUtils;

public class PowerShellTagResource extends AbstractPowerShellActionableResource<Tag> implements TagResource {

    public PowerShellTagResource(String id,
                                 Executor executor,
                                 UriInfoProvider uriProvider,
                                 PowerShellPoolMap shellPools,
                                 PowerShellParser parser) {
        super(id, executor, uriProvider, shellPools, parser);
    }

    public static List<Tag> runAndParse(PowerShellPool pool, PowerShellParser parser, String command) {
        return PowerShellTag.parse(parser, PowerShellCmd.runCommand(pool, command));
    }

    public static Tag runAndParseSingle(PowerShellPool pool, PowerShellParser parser, String command) {
        List<Tag> tags = runAndParse(pool, parser, command);

        return !tags.isEmpty() ? tags.get(0) : null;
    }

    public List<Tag> runAndParse(String command) {
        return runAndParse(getPool(), getParser(), command);
    }

    public Tag runAndParseSingle(String command) {
        return runAndParseSingle(getPool(), getParser(), command);
    }

    @Override
    public Tag get() {
        return LinkHelper.addLinks(getUriInfo(), runAndParseSingle("get-tag " + PowerShellUtils.escape(getId())));
    }

    @Override
    public Tag update(Tag tag) {
        validateUpdate(tag);

        String parentId = null;
        String parentName = null;
        if (tag.isSetParent() && tag.getParent().isSetTag()) {
            if (tag.getParent().getTag().isSetId()) {
                parentId = tag.getParent().getTag().getId();
            } else if (tag.getParent().getTag().isSetName()) {
                parentName = tag.getParent().getTag().getName();
            }
        }

        StringBuilder buf = new StringBuilder();

        buf.append("$t = get-tag " + PowerShellUtils.escape(getId()) + "; ");

        if (parentId != null) {
            buf.append("$parent = get-tag " + PowerShellUtils.escape(parentId) + "; ");
        } else if (parentName != null) {
            buf.append("$parent = get-tags | ? { $_.name -eq " + PowerShellUtils.escape(parentName) + " }; ");
        }

        if (tag.getName() != null) {
            buf.append("$t.name = " + PowerShellUtils.escape(tag.getName()) + "; ");
        }
        if (tag.getDescription() != null) {
            buf.append("$t.description = " + PowerShellUtils.escape(tag.getDescription()) + "; ");
        }

        buf.append("$t = update-tag -tagobject $t; ");

        if (parentId != null || parentName != null) {
            buf.append("if ($t.parentid -ne $parent.tagid) { ");
            buf.append("move-tag -tagobject $t -parenttagobject $parent");
            buf.append(" } ");
        }

        buf.append("$t");

        return LinkHelper.addLinks(getUriInfo(), runAndParseSingle(buf.toString()));
    }
}
